﻿* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung eines Mikrozensus-Trendfiles

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: METAJOB.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.


* Wichtige Hinweise zur Verwendung dieser Syntax finden sich im Readme (readme.pdf).






*----------------------------------------------------   Konfiguration   ---------------------------------------------------.

* Angabe des Verzeichnisses, in dem die einzelnen Mikrozensen (also die Ausgangsdaten) gespeichert sind:
  Ersetzen von VERZEICHNIS_DATEN in die lokale Pfadangabe.
FILE HANDLE pfad_mzdat / NAME='VERZEICHNIS_DATEN'.


* Angabe des Verzeichnisses, in dem die einzelnen Syntaxen zur Harmonisierung gespeichert sind:
  Ersetzen von VERZEICHNIS_SYNTAX in die lokale Pfadangabe.
FILE HANDLE pfad_syntax / NAME='VERZEICHNIS_SYNTAX'.


* Angabe des Verzeichnisses, in dem das Mikrozensus-Trendfile gespeichert werden soll:
  Ersetzen von VERZEICHNIS_TRENDFILE in die lokale Pfadanagabe.
FILE HANDLE pfad_kumdat / NAME='VERZEICHNIS_TRENDFILE'.


* Maximalzahl von Warnungen (etwa wegen langer Value Labels) erhoehen.
SET MXWARNS=100000.


* Soll das GESIS Mikrozensus-Trendfile mit allen Mikrozensen von 1962 bis 2016 erstellt werden,
  sind ab hier keine weiteren Aenderungen mehr noetig.

* Soll das GESIS Mikrozensus-Trendfile nur mit ausgewaehlten Mikrozensen erstellt werden,
  muessen einzelne der folgenden Befehle auskommentiert und/oder angepasst werden
  (siehe Hinweis in den jeweiligen Abschitten).


* Die Syntax erzeugt gegebenenfalls Warn- und/oder Fehlermeldungen bei der Vergabe von Labels
  und Formaten. Die Funktionalitaet der Syntax wird dadurch nicht eingeschraenkt.





*---------------------------------------------------   Harmonisierung   ---------------------------------------------------.

* Sollen nicht alle Mikrozensen zur Erstellung des GESIS Mikrozensus-Trendfiles verwendet werden,
  muss die Syntax zur Harmonisierung der betreffenden Erhebungsjahre auskommentiert werden.


* Mikrozensus GESIS-File 1962.
GET FILE='pfad_mzdat/1962/mz1962.sav'.
INCLUDE FILE='pfad_syntax/methvar62.sps'.
INCLUDE FILE='pfad_syntax/standards62.sps'.
INCLUDE FILE='pfad_syntax/region62.sps'.
INCLUDE FILE='pfad_syntax/erwerb62.sps'.
INCLUDE FILE='pfad_syntax/eink62.sps'.
INCLUDE FILE='pfad_syntax/fam62.sps'.
INCLUDE FILE='pfad_syntax/nat62.sps'.
INCLUDE FILE='pfad_syntax/ges62.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1962.sav'
    / KEEP=
      vers_met idnr hhnr pge hge pgeh hgeh zwerw
      vers_sta jahr pnr bpriv bhws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 abstd_2 stib_1 alo_1 alo_2 sek
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 west sth_t
      vers_fam sthh_1 ephh hhanz hhk_1 hhk_2 ehej
      vers_nat deu_1 nat_1 zuzug_1 zost vert
      vers_ges katyp_1 kaart.

* Mikrozensus GESIS-File 1963.
GET FILE='pfad_mzdat/1963/mz1963.sav'.
INCLUDE FILE='pfad_syntax/methvar63.sps'.
INCLUDE FILE='pfad_syntax/standards63.sps'.
INCLUDE FILE='pfad_syntax/region63.sps'.
INCLUDE FILE='pfad_syntax/erwerb63.sps'.
INCLUDE FILE='pfad_syntax/eink63.sps'.
INCLUDE FILE='pfad_syntax/fam63.sps'.
INCLUDE FILE='pfad_syntax/nat63.sps'.
INCLUDE FILE='pfad_syntax/ges63.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1963.sav'
    / KEEP=
      vers_met idnr hhnr pge hge pgeh hgeh zwerw
      vers_sta jahr pnr bpriv bhws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 abstd_2 stib_1 alo_1 alo_2 sek
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 west sth_t
      vers_fam sthh_1 ephh hhanz hhk_1 hhk_2 ehej
      vers_nat deu_1 nat_1 zuzug_1 zost vert
      vers_ges katyp_1 kaart.

* Mikrozensus GESIS-File 1964.
GET FILE='pfad_mzdat/1964/mz1964.sav'.
INCLUDE FILE='pfad_syntax/methvar64.sps'.
INCLUDE FILE='pfad_syntax/standards64.sps'.
INCLUDE FILE='pfad_syntax/region64.sps'.
INCLUDE FILE='pfad_syntax/erwerb64.sps'.
INCLUDE FILE='pfad_syntax/eink64.sps'.
INCLUDE FILE='pfad_syntax/fam64.sps'.
INCLUDE FILE='pfad_syntax/nat64.sps'.
INCLUDE FILE='pfad_syntax/ges64.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1964.sav'
    / KEEP=
      vers_met idnr hhnr erg pge hge pgeh hgeh zwerw
      vers_sta jahr pnr bpriv bhws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 mith abstd_2 stib_1 alo_1 alo_2 sek
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 west sth_t
      vers_fam sthh_1 ephh hhanz hhk_1 hhk_2 ehej
      vers_nat deu_1 nat_1 zuzug_1 zost vert
      vers_ges katyp_1 kapri kaart.

* Mikrozensus GESIS-File 1965.
GET FILE='pfad_mzdat/1965/mz1965.sav'.
INCLUDE FILE='pfad_syntax/methvar65.sps'.
INCLUDE FILE='pfad_syntax/standards65.sps'.
INCLUDE FILE='pfad_syntax/region65.sps'.
INCLUDE FILE='pfad_syntax/erwerb65.sps'.
INCLUDE FILE='pfad_syntax/eink65.sps'.
INCLUDE FILE='pfad_syntax/fam65.sps'.
INCLUDE FILE='pfad_syntax/nat65.sps'.
INCLUDE FILE='pfad_syntax/ges65.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1965.sav'
    / KEEP=
      vers_met idnr hhnr erg pge hge pgeh hgeh zwerw
      vers_sta jahr pnr bpriv bhws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 mith abstd_2 stib_1 alo_1 alo_2 sek
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 west sth_t
      vers_fam sthh_1 ephh hhanz hhk_1 hhk_2 ehej
      vers_nat deu_1 nat_1 zuzug_1 zost vert
      vers_ges katyp_1 kapri kaart.

* Mikrozensus GESIS-File 1966.
GET FILE='pfad_mzdat/1966/mz1966.sav'.
INCLUDE FILE='pfad_syntax/methvar66.sps'.
INCLUDE FILE='pfad_syntax/standards66.sps'.
INCLUDE FILE='pfad_syntax/region66.sps'.
INCLUDE FILE='pfad_syntax/erwerb66.sps'.
INCLUDE FILE='pfad_syntax/eink66.sps'.
INCLUDE FILE='pfad_syntax/fam66.sps'.
INCLUDE FILE='pfad_syntax/nat66.sps'.
INCLUDE FILE='pfad_syntax/ges66.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1966.sav'
    / KEEP=
      vers_met idnr hhnr erg pge hge pgeh hgeh zwerw
      vers_sta jahr pnr bpriv bhws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 mith abstd_2 stib_1 alo_1 alo_2 sek
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 west sth_t
      vers_fam sthh_1 sthh_2 ephh hhanz hhk_1 hhk_2 famtyp_1 ehej
      vers_nat deu_1 nat_1 zuzug_1 zost vert
      vers_ges katyp_1 kapri kaart.

* Mikrozensus GESIS-File 1967.
GET FILE='pfad_mzdat/1967/mz1967.sav'.
INCLUDE FILE='pfad_syntax/methvar67.sps'.
INCLUDE FILE='pfad_syntax/standards67.sps'.
INCLUDE FILE='pfad_syntax/region67.sps'.
INCLUDE FILE='pfad_syntax/erwerb67.sps'.
INCLUDE FILE='pfad_syntax/eink67.sps'.
INCLUDE FILE='pfad_syntax/fam67.sps'.
INCLUDE FILE='pfad_syntax/nat67.sps'.
INCLUDE FILE='pfad_syntax/ges67.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1967.sav'
    / KEEP=
      vers_met idnr hhnr erg pge hge pgeh hgeh zwerw
      vers_sta jahr pnr bpriv bhws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 mith abstd_2 stib_1 alo_1 alo_2 sek
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 west sth_t
      vers_fam sthh_1 sthh_2 ephh hhanz hhk_1 hhk_2 famtyp_1 ehej
      vers_nat deu_1 nat_1 zuzug_1 zost vert frwo
      vers_ges katyp_1 kapri kaart.

* Mikrozensus GESIS-File 1968.
GET FILE='pfad_mzdat/1968/mz1968.sav'.
INCLUDE FILE='pfad_syntax/methvar68.sps'.
INCLUDE FILE='pfad_syntax/standards68.sps'.
INCLUDE FILE='pfad_syntax/region68.sps'.
INCLUDE FILE='pfad_syntax/erwerb68.sps'.
INCLUDE FILE='pfad_syntax/eink68.sps'.
INCLUDE FILE='pfad_syntax/fam68.sps'.
INCLUDE FILE='pfad_syntax/nat68.sps'.
INCLUDE FILE='pfad_syntax/ges68.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1968.sav'
    / KEEP=
      vers_met idnr hhnr erg pge hge pgeh hgeh zwerw
      vers_sta jahr pnr bpriv bhws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 mith abstd_2 stib_1 alo_1 alo_2 sek
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 west sth_t
      vers_fam sthh_1 sthh_2 ephh hhanz hhk_1 hhk_2 famnr pfnr famanz famk_1 famk_2
           famtyp_1 ehej
      vers_nat deu_1 nat_1 zuzug_1 zost vert 
      vers_ges katyp_1 kapri kaart.

* Mikrozensus GESIS-File 1969.
GET FILE='pfad_mzdat/1969/mz1969.sav'.
INCLUDE FILE='pfad_syntax/methvar69.sps'.
INCLUDE FILE='pfad_syntax/standards69.sps'.
INCLUDE FILE='pfad_syntax/region69.sps'.
INCLUDE FILE='pfad_syntax/erwerb69.sps'.
INCLUDE FILE='pfad_syntax/eink69.sps'.
INCLUDE FILE='pfad_syntax/fam69.sps'.
INCLUDE FILE='pfad_syntax/nat69.sps'.
INCLUDE FILE='pfad_syntax/ges69.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1969.sav'
    / KEEP=
      vers_met idnr hhnr erg pge hge pgeh hgeh zwerw
      vers_sta jahr pnr bpriv bhws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 mith abstd_2 stib_1 alo_1 alo_2 sek
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 west sth_t
      vers_fam sthh_1 sthh_2 ephh hhanz hhk_1 hhk_2 famnr pfnr famanz famk_1 famk_2
           famtyp_1 ehej
      vers_nat deu_1 nat_1 zuzug_1 zost frwo vert
      vers_ges katyp_1 kapri kaart.

* Mikrozensus SUF 1973.
GET FILE='pfad_mzdat/1973/mz1973.sav'.
INCLUDE FILE='pfad_syntax/methvar73.sps'.
INCLUDE FILE='pfad_syntax/standards73.sps'.
INCLUDE FILE='pfad_syntax/region73.sps'.
INCLUDE FILE='pfad_syntax/erwerb73.sps'.
INCLUDE FILE='pfad_syntax/eink73.sps'.
INCLUDE FILE='pfad_syntax/fam73.sps'.
INCLUDE FILE='pfad_syntax/nat73.sps'.
INCLUDE FILE='pfad_syntax/ges73.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1973.sav'
    / KEEP=
      vers_met idnr hhnr sld pge hge pgeh hgeh
      vers_sta jahr pnr bpriv bhws bfws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 zwerw mith abstd_1 abstd_2 stib_1 vztz alo_1 alo_2 mps bk sek beruf_1
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej
      vers_nat deu_1 nat_1 zost frwo vert
      vers_ges katyp_1 kapri kaart.

* Mikrozensus SUF 1976.
GET FILE='pfad_mzdat/1976/mz1976.sav'.
INCLUDE FILE='pfad_syntax/methvar76.sps'.
INCLUDE FILE='pfad_syntax/standards76.sps'.
INCLUDE FILE='pfad_syntax/region76.sps'.
INCLUDE FILE='pfad_syntax/erwerb76.sps'.
INCLUDE FILE='pfad_syntax/bildung76.sps'.
INCLUDE FILE='pfad_syntax/eink76.sps'.
INCLUDE FILE='pfad_syntax/fam76.sps'.
INCLUDE FILE='pfad_syntax/nat76.sps'.
INCLUDE FILE='pfad_syntax/ges76.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1976.sav'
    / KEEP=
      vers_met idnr hhnr sld pge hge pgeh hgeh
      vers_sta jahr pnr bpriv bhws bfws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 zwerw mith abstd_1 abstd_2 stib_1 alo_1 alo_2 mps bk sek beruf_1
      vers_bil kiga sbes schul_1 schul_2 asa_1 asa_2 berab bab_1 wbber wbdau wbort
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej
      vers_nat deu_1 nat_1 zuzug_2
      vers_ges katyp_1 katyp_2 kapri kaart.

* Mikrozensus SUF 1978.
GET FILE='pfad_mzdat/1978/mz1978.sav'.
INCLUDE FILE='pfad_syntax/methvar78.sps'.
INCLUDE FILE='pfad_syntax/standards78.sps'.
INCLUDE FILE='pfad_syntax/region78.sps'.
INCLUDE FILE='pfad_syntax/erwerb78.sps'.
INCLUDE FILE='pfad_syntax/bildung78.sps'.
INCLUDE FILE='pfad_syntax/eink78.sps'.
INCLUDE FILE='pfad_syntax/fam78.sps'.
INCLUDE FILE='pfad_syntax/nat78.sps'.
INCLUDE FILE='pfad_syntax/ges78.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1978.sav'
    / KEEP=
      vers_met idnr hhnr sld pge hge pgeh hgeh
      vers_sta jahr pnr bpriv bhws bfws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 zwerw mith abstd_1 abstd_2 stib_1 alo_1 alo_2 mps bk sek beruf_1
      vers_bil kiga sbes schul_1 schul_2 asa_1 asa_2 berab bab_1 wbber wbdau wbort
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej
      vers_nat deu_1 nat_1 zuzug_2
      vers_ges katyp_1 katyp_2 kapri kaart.

* Mikrozensus SUF 1980.
GET FILE='pfad_mzdat/1980/mz1980.sav'.
INCLUDE FILE='pfad_syntax/methvar80.sps'.
INCLUDE FILE='pfad_syntax/standards80.sps'.
INCLUDE FILE='pfad_syntax/region80.sps'.
INCLUDE FILE='pfad_syntax/erwerb80.sps'.
INCLUDE FILE='pfad_syntax/bildung80.sps'.
INCLUDE FILE='pfad_syntax/eink80.sps'.
INCLUDE FILE='pfad_syntax/fam80.sps'.
INCLUDE FILE='pfad_syntax/nat80.sps'.
INCLUDE FILE='pfad_syntax/ges80.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1980.sav'
    / KEEP=
      vers_met idnr hhnr pge hge pgeh hgeh
      vers_sta jahr pnr bpriv bhws bfws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 zwerw mith abstd_1 abstd_2 stib_1 alo_1 alo_2 mps bk sek beruf_1
      vers_bil kiga sbes schul_1 schul_2 asa_1 asa_2 berab bab_1 wbber wbdau wbort
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej
      vers_nat deu_1 nat_1 zuzug_2
      vers_ges katyp_1 katyp_2 kapri kaart.

* Mikrozensus SUF 1982.
GET FILE='pfad_mzdat/1982/mz1982.sav'.
INCLUDE FILE='pfad_syntax/methvar82.sps'.
INCLUDE FILE='pfad_syntax/standards82.sps'.
INCLUDE FILE='pfad_syntax/region82.sps'.
INCLUDE FILE='pfad_syntax/erwerb82.sps'.
INCLUDE FILE='pfad_syntax/bildung82.sps'.
INCLUDE FILE='pfad_syntax/eink82.sps'.
INCLUDE FILE='pfad_syntax/fam82.sps'.
INCLUDE FILE='pfad_syntax/nat82.sps'.
INCLUDE FILE='pfad_syntax/ges82.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1982.sav'
    / KEEP=
      vers_met idnr hhnr sld pge hge pgeh hgeh
      vers_sta jahr pnr bpriv bhws bfws gesch alter gebj famst
      vers_reg land wost gemgr_1
      vers_erw erw_1 zwerw mith abstd_1 abstd_2 stib_1 alo_1 alo_2 mps bk sek beruf_1
      vers_bil kiga sbes schul_1 schul_2 asa_1 asa_2 berab bab_1 wbber wbdau wbort
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej
      vers_nat deu_1 nat_1 zuzug_2
      vers_ges katyp_1 katyp_2 kapri kaart.

* Mikrozensus SUF 1985.
GET FILE='pfad_mzdat/1985/mz1985.sav'.
INCLUDE FILE='pfad_syntax/methvar85.sps'.
INCLUDE FILE='pfad_syntax/standards85.sps'.
INCLUDE FILE='pfad_syntax/region85.sps'.
INCLUDE FILE='pfad_syntax/erwerb85.sps'.
INCLUDE FILE='pfad_syntax/bildung85.sps'.
INCLUDE FILE='pfad_syntax/eink85.sps'.
INCLUDE FILE='pfad_syntax/fam85.sps'.
INCLUDE FILE='pfad_syntax/nat85.sps'.
INCLUDE FILE='pfad_syntax/ges85.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1985.sav'
    / KEEP=
      vers_met idnr hhnr pge hge pgeh hgeh 
      vers_sta jahr pnr bpriv bhws bfws gesch alter gebj famst
      vers_reg land wost gemgr_1 
      vers_erw erw_1 erw_2 mith  zwerw abstd_1 abstd_2 stib_1 stib_2 vztz frist_1 alo_1 alo_2 bk
           mps sek beruf_1
      vers_bil kiga sbes schul_1 schul_2 asa_1 asa_2 berab bab_1 wbber wbdau wbort
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej
      vers_nat deu_1 nat_1 zuzug_2
      vers_ges katyp_1 katyp_2 kapri kaart.

* Mikrozensus SUF 1987.
GET FILE='pfad_mzdat/1987/mz1987.sav'.
INCLUDE FILE='pfad_syntax/methvar87.sps'.
INCLUDE FILE='pfad_syntax/standards87.sps'.
INCLUDE FILE='pfad_syntax/region87.sps'.
INCLUDE FILE='pfad_syntax/erwerb87.sps'.
INCLUDE FILE='pfad_syntax/bildung87.sps'.
INCLUDE FILE='pfad_syntax/eink87.sps'.
INCLUDE FILE='pfad_syntax/fam87.sps'.
INCLUDE FILE='pfad_syntax/nat87.sps'.
INCLUDE FILE='pfad_syntax/ges87.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1987.sav'
    / KEEP=
      vers_met idnr hhnr pge hge pgeh hgeh 
      vers_sta jahr pnr bpriv bhws bfws gesch alter gebj famst
      vers_reg land wost gemgr_1 
      vers_erw erw_1 erw_2 mith  zwerw abstd_1 abstd_2 stib_1 stib_2 vztz frist_1 alo_1 alo_2 bk
           mps sek beruf_1
      vers_bil kiga sbes schul_1 schul_2 asa_1 asa_2 berab bab_1 wbber wbdau wbort
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej
      vers_nat deu_1 nat_1 zuzug_2
      vers_ges katyp_1 katyp_2 kapri kaart.

* Mikrozensus SUF 1989.
GET FILE='pfad_mzdat/1989/mz1989.sav'.
INCLUDE FILE='pfad_syntax/methvar89.sps'.
INCLUDE FILE='pfad_syntax/standards89.sps'.
INCLUDE FILE='pfad_syntax/region89.sps'.
INCLUDE FILE='pfad_syntax/erwerb89.sps'.
INCLUDE FILE='pfad_syntax/bildung89.sps'.
INCLUDE FILE='pfad_syntax/eink89.sps'.
INCLUDE FILE='pfad_syntax/fam89.sps'.
INCLUDE FILE='pfad_syntax/nat89.sps'.
INCLUDE FILE='pfad_syntax/ges89.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1989.sav'
    / KEEP=
      vers_met idnr pge hge pgeh hgeh uspg
      vers_sta jahr hhnr pnr bpriv bhws bfws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 mith gebes zwerw abstd_1 abstd_2 stib_1 stib_2 vztz frist_1 oeff alo_1
           alo_2 bk mps sek beruf_1
      vers_bil kiga sbes schul_1 schul_2 asa_1 asa_2 berab bab_1 wbber wbdau wbort
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej
      vers_nat deu_1 nat_1 zuzug_2
      vers_ges jodve jodgr rauje raueh raube rauar rauzi krank krje krdau behan kkhda arbun unfal
           behin behgd katyp_1 katyp_2 kapri kaart.

* Mikrozensus SUF 1991.
GET FILE='pfad_mzdat/1991/mz1991.sav'.
INCLUDE FILE='pfad_syntax/methvar91.sps'.
INCLUDE FILE='pfad_syntax/standards91.sps'.
INCLUDE FILE='pfad_syntax/region91.sps'.
INCLUDE FILE='pfad_syntax/erwerb91.sps'.
INCLUDE FILE='pfad_syntax/bildung91.sps'.
INCLUDE FILE='pfad_syntax/eink91.sps'.
INCLUDE FILE='pfad_syntax/fam91.sps'.
INCLUDE FILE='pfad_syntax/nat91.sps'.
INCLUDE FILE='pfad_syntax/ges91.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1991.sav'
    / KEEP=
      vers_met idnr pge hge pgeh hgeh
      vers_sta jahr hhnr pnr bpriv bhws bfws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 gebes stib_1 stib_2 vztz frist_1 oeff alo_1
           alo_2 bk mps sek beruf_1
      vers_bil kiga sbes sab schul_2 schul_3 sab asa_1 asa_2 berab bab_1 wbber wbdau wbort
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej
      vers_nat deu_1 nat_1 zuzug_2
      vers_ges katyp_1 katyp_2 kapri kaart.

* Mikrozensus SUF 1993.
GET FILE='pfad_mzdat/1993/mz1993.sav'.
INCLUDE FILE='pfad_syntax/methvar93.sps'.
INCLUDE FILE='pfad_syntax/standards93.sps'.
INCLUDE FILE='pfad_syntax/region93.sps'.
INCLUDE FILE='pfad_syntax/erwerb93.sps'.
INCLUDE FILE='pfad_syntax/bildung93.sps'.
INCLUDE FILE='pfad_syntax/eink93.sps'.
INCLUDE FILE='pfad_syntax/fam93.sps'.
INCLUDE FILE='pfad_syntax/nat93.sps'.
INCLUDE FILE='pfad_syntax/ges93.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1993.sav'
    / KEEP=
      vers_met idnr pge hge pgeh hgeh
      vers_sta jahr hhnr pnr bpriv bhws bfws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 gebes stib_1 vztz frist_1 oeff alo_1 alo_2
           bk mps sek beruf_2
      vers_bil kiga sbes sab schul_2 schul_3 sab asa_1 asa_2 berab bab_1 wbber wbdau wbort
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej
      vers_nat deu_1 nat_1 zuzug_2
      vers_ges katyp_1 katyp_2 kapri kaart.

* Mikrozensus SUF 1995.
GET FILE='pfad_mzdat/1995/mz1995.sav'.
INCLUDE FILE='pfad_syntax/methvar95.sps'.
INCLUDE FILE='pfad_syntax/standards95.sps'.
INCLUDE FILE='pfad_syntax/region95.sps'.
INCLUDE FILE='pfad_syntax/erwerb95.sps'.
INCLUDE FILE='pfad_syntax/bildung95.sps'.
INCLUDE FILE='pfad_syntax/eink95.sps'.
INCLUDE FILE='pfad_syntax/fam95.sps'.
INCLUDE FILE='pfad_syntax/nat95.sps'.
INCLUDE FILE='pfad_syntax/ges95.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1995.sav'
    / KEEP=
      vers_met idnr pge hge pgeh hgeh uspg
      vers_sta jahr hhnr pnr bpriv bhws bfws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 gebes stib_1 vztz frist_1 oeff alo_1 alo_2
           bk mps sek beruf_2
      vers_bil kiga sbes sab schul_2 schul_3 sab asa_1 asa_2 berab bab_1 wbber wbdau wbort
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej
      vers_nat deu_1 nat_1 zuzug_2
      vers_ges jodve jodgr rauje raueh raube rauar rauzi krank krje krdau behan kkhda arbun unfal
           behin behgd katyp_1 katyp_2 kapri kaart.

* Mikrozensus SUF 1996.
GET FILE='pfad_mzdat/1996/mz1996.sav'.
INCLUDE FILE='pfad_syntax/methvar96.sps'.
INCLUDE FILE='pfad_syntax/standards96.sps'.
INCLUDE FILE='pfad_syntax/region96.sps'.
INCLUDE FILE='pfad_syntax/erwerb96.sps'.
INCLUDE FILE='pfad_syntax/bildung96.sps'.
INCLUDE FILE='pfad_syntax/eink96.sps'.
INCLUDE FILE='pfad_syntax/fam96.sps'.
INCLUDE FILE='pfad_syntax/nat96.sps'.
INCLUDE FILE='pfad_syntax/ges96.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1996.sav'
    / KEEP=
      vers_met idnr pge pgeu hge pgeh pgeuh hgeh usp uspg bef_1
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil kiga sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbdau wbort
           wbstd wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 ausst
      vers_ges hilfe hilfk hilfn hilfb hilfv hilfh pflei pfstu.

* Mikrozensus SUF 1997.
GET FILE='pfad_mzdat/1997/mz1997.sav'.
INCLUDE FILE='pfad_syntax/methvar97.sps'.
INCLUDE FILE='pfad_syntax/standards97.sps'.
INCLUDE FILE='pfad_syntax/region97.sps'.
INCLUDE FILE='pfad_syntax/erwerb97.sps'.
INCLUDE FILE='pfad_syntax/bildung97.sps'.
INCLUDE FILE='pfad_syntax/eink97.sps'.
INCLUDE FILE='pfad_syntax/fam97.sps'.
INCLUDE FILE='pfad_syntax/nat97.sps'.
INCLUDE FILE='pfad_syntax/ges97.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1997.sav'
    / KEEP=
      vers_met idnr pge pgeu hge pgeh pgeuh hgeh usp uspg bef_1
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil kiga sbes sab schul_2 schul_3  asa_1 asa_2 berab bab_1 bab_2 wbber wbdau wbort
           wbstd wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 ausst
      vers_ges hilfe hilfk hilfn hilfb hilfv hilfh pflei pfstu.

* Mikrozensus SUF 1998.
GET FILE='pfad_mzdat/1998/mz1998.sav'.
INCLUDE FILE='pfad_syntax/methvar98.sps'.
INCLUDE FILE='pfad_syntax/standards98.sps'.
INCLUDE FILE='pfad_syntax/region98.sps'.
INCLUDE FILE='pfad_syntax/erwerb98.sps'.
INCLUDE FILE='pfad_syntax/bildung98.sps'.
INCLUDE FILE='pfad_syntax/eink98.sps'.
INCLUDE FILE='pfad_syntax/fam98.sps'.
INCLUDE FILE='pfad_syntax/nat98.sps'.
INCLUDE FILE='pfad_syntax/ges98.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1998.sav'
    / KEEP=
      vers_met idnr pge pgeu hge pgeh pgeuh hgeh usp uspg bef_1
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil kiga sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbdau wbort
           wbstd wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 ausst
      vers_ges hilfe hilfk hilfn hilfb hilfv hilfh pflei pfstu.

* Mikrozensus SUF 1999.
GET FILE='pfad_mzdat/1999/mz1999.sav'.
INCLUDE FILE='pfad_syntax/methvar99.sps'.
INCLUDE FILE='pfad_syntax/standards99.sps'.
INCLUDE FILE='pfad_syntax/region99.sps'.
INCLUDE FILE='pfad_syntax/erwerb99.sps'.
INCLUDE FILE='pfad_syntax/bildung99.sps'.
INCLUDE FILE='pfad_syntax/eink99.sps'.
INCLUDE FILE='pfad_syntax/fam99.sps'.
INCLUDE FILE='pfad_syntax/nat99.sps'.
INCLUDE FILE='pfad_syntax/ges99.sps'.
SAVE OUTFILE='pfad_kumdat/dat_1999.sav'
    / KEEP=
      vers_met idnr pge pgeu hge hgeu pgeh pgeuh hgeh hgeuh usp uspg bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil kiga sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbdau wbort
           wbstd wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges centi kilo rauje raueh raube rauar rauzi impf krank krje krdau behan unfal krerw hilfe hilfk
           hilfn hilfb hilfv hilfh pflei pfstu behin behgd kavrs katyp_1 katyp_2 kapri kaart.

* Mikrozensus SUF 2000.
GET FILE='pfad_mzdat/2000/mz2000.sav'.
INCLUDE FILE='pfad_syntax/methvar00.sps'.
INCLUDE FILE='pfad_syntax/standards00.sps'.
INCLUDE FILE='pfad_syntax/region00.sps'.
INCLUDE FILE='pfad_syntax/erwerb00.sps'.
INCLUDE FILE='pfad_syntax/bildung00.sps'.
INCLUDE FILE='pfad_syntax/eink00.sps'.
INCLUDE FILE='pfad_syntax/fam00.sps'.
INCLUDE FILE='pfad_syntax/nat00.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2000.sav'
    / KEEP=
      vers_met idnr pge pgeu hge hgeu pgeh pgeuh hgeh hgeuh usp bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil kiga sbes sab schul_2 schul_3  asa_1 asa_2 berab bab_1 bab_2 wbber wbdau wbort
           wbstd wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst.

* Mikrozensus SUF 2001.
GET FILE='pfad_mzdat/2001/mz2001.sav'.
INCLUDE FILE='pfad_syntax/methvar01.sps'.
INCLUDE FILE='pfad_syntax/standards01.sps'.
INCLUDE FILE='pfad_syntax/region01.sps'.
INCLUDE FILE='pfad_syntax/erwerb01.sps'.
INCLUDE FILE='pfad_syntax/bildung01.sps'.
INCLUDE FILE='pfad_syntax/eink01.sps'.
INCLUDE FILE='pfad_syntax/fam01.sps'.
INCLUDE FILE='pfad_syntax/nat01.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2001.sav'
    / KEEP=
      vers_met idnr pge pgeu hge hgeu pgeh pgeuh hgeh hgeuh usp bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil kiga sbes sab schul_2 schul_3  asa_1 asa_2 berab bab_1 bab_2 wbber wbdau wbort
           wbstd wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst.

* Mikrozensus SUF 2002.
GET FILE='pfad_mzdat/2002/mz2002.sav'.
INCLUDE FILE='pfad_syntax/methvar02.sps'.
INCLUDE FILE='pfad_syntax/standards02.sps'.
INCLUDE FILE='pfad_syntax/region02.sps'.
INCLUDE FILE='pfad_syntax/erwerb02.sps'.
INCLUDE FILE='pfad_syntax/bildung02.sps'.
INCLUDE FILE='pfad_syntax/eink02.sps'.
INCLUDE FILE='pfad_syntax/fam02.sps'.
INCLUDE FILE='pfad_syntax/nat02.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2002.sav'
    / KEEP=
      vers_met idnr pge pgeu hge hgeu pgeh pgeuh hgeh hgeuh usp bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil kiga sbes sab schul_2 schul_3  asa_1 asa_2 berab bab_1 bab_2 wbber wbdau wbort
           wbstd wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst.

* Mikrozensus SUF 2003.
GET FILE='pfad_mzdat/2003/mz2003.sav'.
INCLUDE FILE='pfad_syntax/methvar03.sps'.
INCLUDE FILE='pfad_syntax/standards03.sps'.
INCLUDE FILE='pfad_syntax/region03.sps'.
INCLUDE FILE='pfad_syntax/erwerb03.sps'.
INCLUDE FILE='pfad_syntax/bildung03.sps'.
INCLUDE FILE='pfad_syntax/eink03.sps'.
INCLUDE FILE='pfad_syntax/fam03.sps'.
INCLUDE FILE='pfad_syntax/nat03.sps'.
INCLUDE FILE='pfad_syntax/ges03.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2003.sav'
    / KEEP=
      vers_met idnr pge pgeu hge hgeu pgeh pgeuh hgeh hgeuh usp uspg bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes  stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil kiga sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges centi kilo rauje raueh raube rauar rauzi impf krank krje krdau behan unfal krerw hilfe hilfk
           hilfn hilfb hilfv hilfh pflei pfstu behin behgd kavrs katyp_1 katyp_2 kapri kaart.

* Mikrozensus SUF 2004.
GET FILE='pfad_mzdat/2004/mz2004.sav'.
INCLUDE FILE='pfad_syntax/methvar04.sps'.
INCLUDE FILE='pfad_syntax/standards04.sps'.
INCLUDE FILE='pfad_syntax/region04.sps'.
INCLUDE FILE='pfad_syntax/erwerb04.sps'.
INCLUDE FILE='pfad_syntax/bildung04.sps'.
INCLUDE FILE='pfad_syntax/eink04.sps'.
INCLUDE FILE='pfad_syntax/fam04.sps'.
INCLUDE FILE='pfad_syntax/nat04.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2004.sav'
    / KEEP=
      vers_met idnr pge pgeu hge hgeu pgeh pgeuh hgeh hgeuh usp bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil kiga sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 ehej lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst.

* Mikrozensus SUF 2005.
GET FILE='pfad_mzdat/2005/mz2005.sav'.
INCLUDE FILE='pfad_syntax/methvar05.sps'.
INCLUDE FILE='pfad_syntax/standards05.sps'.
INCLUDE FILE='pfad_syntax/region05.sps'.
INCLUDE FILE='pfad_syntax/erwerb05.sps'.
INCLUDE FILE='pfad_syntax/bildung05.sps'.
INCLUDE FILE='pfad_syntax/eink05.sps'.
INCLUDE FILE='pfad_syntax/fam05.sps'.
INCLUDE FILE='pfad_syntax/nat05.sps'.
INCLUDE FILE='pfad_syntax/ges05.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2005.sav'
    / KEEP=
      vers_met idnr pge hge geq pgeh hgeh geqh quar bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges centi kilo rauje raueh raube rauar rauzi krank krje krdau behan unfal pfstu behin behgd.

* Mikrozensus SUF 2006.
GET FILE='pfad_mzdat/2006/mz2006.sav'.
INCLUDE FILE='pfad_syntax/methvar06.sps'.
INCLUDE FILE='pfad_syntax/standards06.sps'.
INCLUDE FILE='pfad_syntax/region06.sps'.
INCLUDE FILE='pfad_syntax/erwerb06.sps'.
INCLUDE FILE='pfad_syntax/bildung06.sps'.
INCLUDE FILE='pfad_syntax/eink06.sps'.
INCLUDE FILE='pfad_syntax/fam06.sps'.
INCLUDE FILE='pfad_syntax/nat06.sps'.
INCLUDE FILE='pfad_syntax/ges06.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2006.sav'
    / KEEP=
      vers_met idnr pge hge geq pgeh hgeh geqh quar bef_1 bef_2 bet jueb
      vers_sta jahr hhnr pnr flaghh bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges pfstu.

* Mikrozensus SUF 2007.
GET FILE='pfad_mzdat/2007/mz2007.sav'.
INCLUDE FILE='pfad_syntax/methvar07.sps'.
INCLUDE FILE='pfad_syntax/standards07.sps'.
INCLUDE FILE='pfad_syntax/region07.sps'.
INCLUDE FILE='pfad_syntax/erwerb07.sps'.
INCLUDE FILE='pfad_syntax/bildung07.sps'.
INCLUDE FILE='pfad_syntax/eink07.sps'.
INCLUDE FILE='pfad_syntax/fam07.sps'.
INCLUDE FILE='pfad_syntax/nat07.sps'.
INCLUDE FILE='pfad_syntax/ges07.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2007.sav'
    / KEEP=
      vers_met idnr pge hge geq pgeh hgeh geqh quar bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges pfstu kavrs katyp_1 katyp_2 kapri.

* Mikrozensus SUF 2008.
GET FILE='pfad_mzdat/2008/mz2008.sav'.
INCLUDE FILE='pfad_syntax/methvar08.sps'.
INCLUDE FILE='pfad_syntax/standards08.sps'.
INCLUDE FILE='pfad_syntax/region08.sps'.
INCLUDE FILE='pfad_syntax/erwerb08.sps'.
INCLUDE FILE='pfad_syntax/bildung08.sps'.
INCLUDE FILE='pfad_syntax/eink08.sps'.
INCLUDE FILE='pfad_syntax/fam08.sps'.
INCLUDE FILE='pfad_syntax/nat08.sps'.
INCLUDE FILE='pfad_syntax/ges08.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2008.sav'
    / KEEP=
      vers_met idnr jueb pge hge geq pgeh hgeh geqh quar bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges pfstu.

* Mikrozensus SUF 2009.
GET FILE='pfad_mzdat/2009/mz2009.sav'.
INCLUDE FILE='pfad_syntax/methvar09.sps'.
INCLUDE FILE='pfad_syntax/standards09.sps'.
INCLUDE FILE='pfad_syntax/region09.sps'.
INCLUDE FILE='pfad_syntax/erwerb09.sps'.
INCLUDE FILE='pfad_syntax/bildung09.sps'.
INCLUDE FILE='pfad_syntax/eink09.sps'.
INCLUDE FILE='pfad_syntax/fam09.sps'.
INCLUDE FILE='pfad_syntax/nat09.sps'.
INCLUDE FILE='pfad_syntax/ges09.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2009.sav'
    / KEEP=
      vers_met idnr jueb pge hge geq pgeh hgeh geqh quar bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges centi kilo rauje raueh raube rauar rauzi krank krje krdau behan unfal pfstu behin behgd.

* Mikrozensus SUF 2010.
GET FILE='pfad_mzdat/2010/mz2010.sav'.
INCLUDE FILE='pfad_syntax/methvar10.sps'.
INCLUDE FILE='pfad_syntax/standards10.sps'.
INCLUDE FILE='pfad_syntax/region10.sps'.
INCLUDE FILE='pfad_syntax/erwerb10.sps'.
INCLUDE FILE='pfad_syntax/bildung10.sps'.
INCLUDE FILE='pfad_syntax/eink10.sps'.
INCLUDE FILE='pfad_syntax/fam10.sps'.
INCLUDE FILE='pfad_syntax/nat10.sps'.
INCLUDE FILE='pfad_syntax/ges10.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2010.sav'
    / KEEP=
      vers_met idnr jueb pge hge geq pgeh hgeh geqh quar bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges pfstu.

* Mikrozensus SUF 2011.
GET FILE='pfad_mzdat/2011/mz2011.sav'.
INCLUDE FILE='pfad_syntax/methvar11.sps'.
INCLUDE FILE='pfad_syntax/standards11.sps'.
INCLUDE FILE='pfad_syntax/region11.sps'.
INCLUDE FILE='pfad_syntax/erwerb11.sps'.
INCLUDE FILE='pfad_syntax/bildung11.sps'.
INCLUDE FILE='pfad_syntax/eink11.sps'.
INCLUDE FILE='pfad_syntax/fam11.sps'.
INCLUDE FILE='pfad_syntax/nat11.sps'.
INCLUDE FILE='pfad_syntax/ges11.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2011.sav'
    / KEEP=
      vers_met idnr jueb pge hge geq pgeh hgeh geqh quar bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2
      vers_bil sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges pfstu kavrs katyp_1 katyp_2 kaart.

* Mikrozensus SUF 2012.
GET FILE='pfad_mzdat/2012/mz2012.sav'.
INCLUDE FILE='pfad_syntax/methvar12.sps'.
INCLUDE FILE='pfad_syntax/standards12.sps'.
INCLUDE FILE='pfad_syntax/region12.sps'.
INCLUDE FILE='pfad_syntax/erwerb12.sps'.
INCLUDE FILE='pfad_syntax/bildung12.sps'.
INCLUDE FILE='pfad_syntax/eink12.sps'.
INCLUDE FILE='pfad_syntax/fam12.sps'.
INCLUDE FILE='pfad_syntax/nat12.sps'.
INCLUDE FILE='pfad_syntax/ges12.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2012.sav'
    / KEEP=
      vers_met idnr jueb pge hge geq pgeh hgeh geqh quar bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_1 isco_2 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 bk isei mps sek beruf_2 beruf_3
      vers_bil sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges pfstu.

* Mikrozensus SUF 2013.
GET FILE='pfad_mzdat/2013/mz2013.sav'.
INCLUDE FILE='pfad_syntax/methvar13.sps'.
INCLUDE FILE='pfad_syntax/standards13.sps'.
INCLUDE FILE='pfad_syntax/region13.sps'.
INCLUDE FILE='pfad_syntax/erwerb13.sps'.
INCLUDE FILE='pfad_syntax/bildung13.sps'.
INCLUDE FILE='pfad_syntax/eink13.sps'.
INCLUDE FILE='pfad_syntax/fam13.sps'.
INCLUDE FILE='pfad_syntax/nat13.sps'.
INCLUDE FILE='pfad_syntax/ges13.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2013.sav'
    / KEEP=
      vers_met idnr jueb pge hge geq pgeh hgeh geqh quar bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_2 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 isei sek beruf_3
      vers_bil sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges centi kilo rauje raueh raube rauar rauzi krank krje krdau behan unfal pfstu behin behgd.

* Mikrozensus SUF 2014.
GET FILE='pfad_mzdat/2014/mz2014.sav'.
INCLUDE FILE='pfad_syntax/methvar14.sps'.
INCLUDE FILE='pfad_syntax/standards14.sps'.
INCLUDE FILE='pfad_syntax/region14.sps'.
INCLUDE FILE='pfad_syntax/erwerb14.sps'.
INCLUDE FILE='pfad_syntax/bildung14.sps'.
INCLUDE FILE='pfad_syntax/eink14.sps'.
INCLUDE FILE='pfad_syntax/fam14.sps'.
INCLUDE FILE='pfad_syntax/nat14.sps'.
INCLUDE FILE='pfad_syntax/ges14.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2014.sav'
    / KEEP=
      vers_met idnr jueb pge hge geq pgeh hgeh geqh quar bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_2 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 isei sek beruf_3
      vers_bil sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges pfstu.

* Mikrozensus SUF 2015.
GET FILE='pfad_mzdat/2015/mz2015.sav'.
INCLUDE FILE='pfad_syntax/methvar15.sps'.
INCLUDE FILE='pfad_syntax/standards15.sps'.
INCLUDE FILE='pfad_syntax/region15.sps'.
INCLUDE FILE='pfad_syntax/erwerb15.sps'.
INCLUDE FILE='pfad_syntax/bildung15.sps'.
INCLUDE FILE='pfad_syntax/eink15.sps'.
INCLUDE FILE='pfad_syntax/fam15.sps'.
INCLUDE FILE='pfad_syntax/nat15.sps'.
INCLUDE FILE='pfad_syntax/ges15.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2015.sav'
    / KEEP=
      vers_met idnr jueb pge hge geq pgeh hgeh geqh quar bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_2 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 isei sek beruf_3
      vers_bil sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges pfstu kavrs katyp_1 katyp_2 kaart.

* Mikrozensus SUF 2016.
GET FILE='pfad_mzdat/2016/mz2016.sav'.
INCLUDE FILE='pfad_syntax/methvar16.sps'.
INCLUDE FILE='pfad_syntax/standards16.sps'.
INCLUDE FILE='pfad_syntax/region16.sps'.
INCLUDE FILE='pfad_syntax/erwerb16.sps'.
INCLUDE FILE='pfad_syntax/bildung16.sps'.
INCLUDE FILE='pfad_syntax/eink16.sps'.
INCLUDE FILE='pfad_syntax/fam16.sps'.
INCLUDE FILE='pfad_syntax/nat16.sps'.
INCLUDE FILE='pfad_syntax/ges16.sps'.
SAVE OUTFILE='pfad_kumdat/dat_2016.sav'
    / KEEP=
      vers_met idnr jueb pge hge geq pgeh hgeh geqh quar bef_1 bef_2 bet
      vers_sta jahr hhnr pnr bpriv bhws bfws blws gesch alter gebj famst
      vers_reg land wost gemgr_1 gemgr_2
      vers_erw erw_1 erw_2 zwerw mith abstd_1 abstd_2 isco_2 gebes stib_1 stib_2 vztz frist_1 frist_2
           oeff alo_1 alo_2 isei sek beruf_3
      vers_bil sbes sab schul_2 schul_3 asa_1 asa_2 berab bab_1 bab_2 wbber wbalg
      vers_ein einkp_1 einkp_2 einkh_1 einkh_2 ebezh ueblu_1 ueblu_2 ueblu_3 west sth_t
      vers_fam sthh_1 sthh_2 sthh_3 ephh hhtyp hhanz hhk_1 hhk_2 famnr pfnr stfam famanz famk_1
           famk_2 famtyp_1 famtyp_2 lgnr plgnr stlg lgtyp lganz lgk_1 lgk_2
      vers_nat deu_1 deu_2 nat_1 nat_2 nat_3 zuzug_2 zuzug_3 ausst
      vers_ges pfstu.





*-----------------------------------------------------   Kumulation   -----------------------------------------------------.

* Wurden nicht alle Mikrozensen zur Erstellung des GESIS Mikrozensus-Trendfiles verwendet,
  muessen die betreffenden Erhebungsjahre aus dem ADD FILES-Befehl entfernt werden.

ADD FILES
    / FILE='pfad_kumdat/dat_1962.sav'
    / FILE='pfad_kumdat/dat_1963.sav'
    / FILE='pfad_kumdat/dat_1964.sav'
    / FILE='pfad_kumdat/dat_1965.sav'
    / FILE='pfad_kumdat/dat_1966.sav'
    / FILE='pfad_kumdat/dat_1967.sav'
    / FILE='pfad_kumdat/dat_1968.sav'
    / FILE='pfad_kumdat/dat_1969.sav'
    / FILE='pfad_kumdat/dat_1973.sav'
    / FILE='pfad_kumdat/dat_1976.sav'
    / FILE='pfad_kumdat/dat_1978.sav'
    / FILE='pfad_kumdat/dat_1980.sav'
    / FILE='pfad_kumdat/dat_1982.sav'
    / FILE='pfad_kumdat/dat_1985.sav'
    / FILE='pfad_kumdat/dat_1987.sav'
    / FILE='pfad_kumdat/dat_1989.sav'
    / FILE='pfad_kumdat/dat_1991.sav'
    / FILE='pfad_kumdat/dat_1993.sav'
    / FILE='pfad_kumdat/dat_1995.sav'
    / FILE='pfad_kumdat/dat_1996.sav'
    / FILE='pfad_kumdat/dat_1997.sav'
    / FILE='pfad_kumdat/dat_1998.sav'
    / FILE='pfad_kumdat/dat_1999.sav'
    / FILE='pfad_kumdat/dat_2000.sav'
    / FILE='pfad_kumdat/dat_2001.sav'
    / FILE='pfad_kumdat/dat_2002.sav'
    / FILE='pfad_kumdat/dat_2003.sav'
    / FILE='pfad_kumdat/dat_2004.sav'
    / FILE='pfad_kumdat/dat_2005.sav'
    / FILE='pfad_kumdat/dat_2006.sav'
    / FILE='pfad_kumdat/dat_2007.sav'
    / FILE='pfad_kumdat/dat_2008.sav'
    / FILE='pfad_kumdat/dat_2009.sav'
    / FILE='pfad_kumdat/dat_2010.sav'
    / FILE='pfad_kumdat/dat_2011.sav'
    / FILE='pfad_kumdat/dat_2012.sav'
    / FILE='pfad_kumdat/dat_2013.sav'
    / FILE='pfad_kumdat/dat_2014.sav'
    / FILE='pfad_kumdat/dat_2015.sav'
    / FILE='pfad_kumdat/dat_2016.sav'.
EXECUTE.

SAVE OUTFILE='pfad_kumdat/mz_trendfile.sav'
    / COMPRESSED.



*----------------------------------------------   Bildungsklassifikationen   ----------------------------------------------.

GET FILE='pfad_kumdat/mz_trendfile.sav'.

INCLUDE FILE='pfad_syntax/bildung_klassifikation.sps'.



*-------------------------------   Aequivalenzeinkommen und relative Einkommensposition   ---------------------------------.

INCLUDE FILE='pfad_syntax/eink_aeq.sps'.
INCLUDE FILE='pfad_syntax/eink_eps.sps'.

SAVE OUTFILE='pfad_kumdat/mz_trendfile.sav'
    / COMPRESSED.



*---------------------------------------   Vergabe von Variablen und Value Labels   ---------------------------------------.

INCLUDE FILE='pfad_syntax/methvar_labels.sps'.
INCLUDE FILE='pfad_syntax/standards_labels.sps'.
INCLUDE FILE='pfad_syntax/region_labels.sps'.
INCLUDE FILE='pfad_syntax/erwerb_labels.sps'.
INCLUDE FILE='pfad_syntax/bildung_labels.sps'.
INCLUDE FILE='pfad_syntax/eink_labels.sps'.
INCLUDE FILE='pfad_syntax/familie_labels.sps'.
INCLUDE FILE='pfad_syntax/nat_labels.sps'.
INCLUDE FILE='pfad_syntax/gesundheit_labels.sps'.



*------------------------   Vergabe von Variablenformaten (zur Vermeidung von Nachkommastellen)   -------------------------.

FORMATS ALL (F4.0).

FORMATS abstd_1 (F2.1).
FORMATS abstd_2 (F2.1).
FORMATS mps (F3.1).
FORMATS pge (F4.2).
FORMATS pgeu (F4.2).
FORMATS hge (F4.2).
FORMATS hgeu (F4.2).
FORMATS pgeh (F4.2).
FORMATS pgeuh (F4.2).
FORMATS hgeh (F4.2).
FORMATS hgeuh (F4.2).
FORMATS geq (F4.2).
FORMATS geqh (F4.2).
FORMATS einkp_1 (F5.2).
FORMATS einkp_2 (F5.2).
FORMATS einkh_1 (F5.2).
FORMATS einkh_2 (F5.2).
FORMATS aeq_1 (F5.2).
FORMATS aeq_2 (F5.2).
FORMATS aeq_3 (F5.2).
FORMATS epos_1 (F4.2).
FORMATS epos_2 (F4.2).
FORMATS hhnr (F6.0).
FORMATS idnr (F10.0).



*----------------------------------------   Speichern des kumulierten Datensatzes   ---------------------------------------.

* Sollen nicht alle, sondern nur ausgewaehlte harmonisierte Variablen im kumulierten Datensatz gespeichert
  werden, muessen diese in einem KEEP-Unterbefehl angegeben werden.

SAVE OUTFILE='pfad_kumdat/mz_trendfile.sav'
    / COMPRESSED.



*----------------------------------   Loeschen der einzelnen harmonisierten Datensaetze   ---------------------------------.

* Wurden nicht alle Mikrozensen zur Erstellung des GESIS Mikrozensus-Trendfiles verwendet,
  muessen die betreffenden Erhebungsjahre aus dem ERASE FILES-Befehl entfernt werden.

ERASE FILE='pfad_kumdat/dat_1962.sav'.
ERASE FILE='pfad_kumdat/dat_1963.sav'.
ERASE FILE='pfad_kumdat/dat_1964.sav'.
ERASE FILE='pfad_kumdat/dat_1965.sav'.
ERASE FILE='pfad_kumdat/dat_1966.sav'.
ERASE FILE='pfad_kumdat/dat_1967.sav'.
ERASE FILE='pfad_kumdat/dat_1968.sav'.
ERASE FILE='pfad_kumdat/dat_1969.sav'.
ERASE FILE='pfad_kumdat/dat_1973.sav'.
ERASE FILE='pfad_kumdat/dat_1976.sav'.
ERASE FILE='pfad_kumdat/dat_1978.sav'.
ERASE FILE='pfad_kumdat/dat_1980.sav'.
ERASE FILE='pfad_kumdat/dat_1982.sav'.
ERASE FILE='pfad_kumdat/dat_1985.sav'.
ERASE FILE='pfad_kumdat/dat_1987.sav'.
ERASE FILE='pfad_kumdat/dat_1989.sav'.
ERASE FILE='pfad_kumdat/dat_1991.sav'.
ERASE FILE='pfad_kumdat/dat_1993.sav'.
ERASE FILE='pfad_kumdat/dat_1995.sav'.
ERASE FILE='pfad_kumdat/dat_1996.sav'.
ERASE FILE='pfad_kumdat/dat_1997.sav'.
ERASE FILE='pfad_kumdat/dat_1998.sav'.
ERASE FILE='pfad_kumdat/dat_1999.sav'.
ERASE FILE='pfad_kumdat/dat_2000.sav'.
ERASE FILE='pfad_kumdat/dat_2001.sav'.
ERASE FILE='pfad_kumdat/dat_2002.sav'.
ERASE FILE='pfad_kumdat/dat_2003.sav'.
ERASE FILE='pfad_kumdat/dat_2004.sav'.
ERASE FILE='pfad_kumdat/dat_2005.sav'.
ERASE FILE='pfad_kumdat/dat_2006.sav'.
ERASE FILE='pfad_kumdat/dat_2007.sav'.
ERASE FILE='pfad_kumdat/dat_2008.sav'.
ERASE FILE='pfad_kumdat/dat_2009.sav'.
ERASE FILE='pfad_kumdat/dat_2010.sav'.
ERASE FILE='pfad_kumdat/dat_2011.sav'.
ERASE FILE='pfad_kumdat/dat_2012.sav'.
ERASE FILE='pfad_kumdat/dat_2013.sav'.
ERASE FILE='pfad_kumdat/dat_2014.sav'.
ERASE FILE='pfad_kumdat/dat_2015.sav'.
ERASE FILE='pfad_kumdat/dat_2016.sav'.

