﻿* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung des Aequivalenzeinkommens.
* Themenbereich Einkommen


*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: eink_aeq.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

* Versionsnummer des Moduls 'Einkommen'.
COMPUTE vers_ein=5.


*----------------------------------------------   Erste Person im Haushalt   ----------------------------------------------.

* entweder Bezugsperson oder, wenn es keine Bezugsperson oder mehrere Bezugspersonen gibt, aelteste Person.
SORT CASES BY jahr(A) hhnr(A) sth_t(A) alter(D).
IF (jahr>LAG(jahr) OR hhnr>LAG(hhnr)) hbp=1.
IF $CASENUM=1 hbp=1.
RECODE hbp (SYSMIS=0) (ELSE=COPY).
EXECUTE.


*----------------------------------------   Aequivalenzeinkommen, preisbereinigt   ----------------------------------------.

*---   Bedarfsgewichtung nach alter OECD-Skala   ---.

* Gewichtungsfaktor 1 fuer erste Person im Haushalt.
* Gewichtungsfaktor 0,7 fuer weitere Personen im Haushalt, die 14 Jahre oder aelter sind.
* Gewichtungsfaktor 0,5 fuer weitere Personen im Haushalt, die 13 Jahre oder juenger sind.

* Hilfsvariable a=1, wenn weitere Person im Haushalt 14 Jahre oder aelter ist (sonst a=0).
COMPUTE a=0.
IF (hbp=0 AND alter>=14) a=1.
EXECUTE.

* Hilfsvariable b=1, wenn weitere Person im Haushalt 13 Jahre oder juenger ist (sonst b=0).
COMPUTE b=0.
IF (hbp=0 AND alter<14) b=1.
EXECUTE.

* Anzahl der mit a=1 und b=1 markierten Personen im Haushalt.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK jahr hhnr
   / anz_a=SUM(a)
   / anz_b=SUM(b).
EXECUTE.

* Berechnung des Aequivalenzeinkommens.
IF einkh_2>=0 aeq_1=einkh_2 / (1+(anz_a*0.7)+(anz_b*0.5)).
IF einkh_2<0 aeq_1=einkh_2.
EXECUTE.


*---   Bedarfsgewichtung nach neuer OECD-Skala   ---.

* Gewichtungsfaktor 1 fuer erste Person im Haushalt.
* Gewichtungsfaktor 0,5 fuer weitere Personen im Haushalt, die 14 Jahre oder aelter sind.
* Gewichtungsfaktor 0,3 fuer weitere Personen im Haushalt, die 13 Jahre oder juenger sind.

* Berechnung des Aequivalenzeinkommens.
IF einkh_2>=0 aeq_2=einkh_2 / (1+(anz_a*0.5)+(anz_b*0.3)).
IF einkh_2<0 aeq_2=einkh_2.
EXECUTE.


*---   Bedarfsgewichtung nach vereinfachter BSHG-Skala   ---.

* Gewichtungsfaktor 1 fuer erste Person im Haushalt.
* Gewichtungsfaktor 0,8 fuer weitere Personen im Haushalt, die 18 Jahre oder aelter sind.
* Gewichtungsfaktor 0,9 fuer weitere Personen im Haushalt, die zwischen 14 und 17 Jahre alt sind.
* Gewichtungsfaktor 0,65 fuer weitere Personen im Haushalt, die zwischen 7 und 13 Jahre alt sind.
* Gewichtungsfaktor 0,5 fuer weitere Personen im Haushalt, die 6 Jahre alt oder juenger sind.

* Hilfsvariable c=1, wenn weitere Person im Haushalt 18 Jahre oder aelter ist (sonst c=0).
COMPUTE c=0.
IF (hbp=0 AND alter>=18) c=1.
EXECUTE.

* Hilfsvariable d=1, wenn weitere Person im Haushalt zwischen 14 und 17 Jahre alt ist (sonst d=0).
COMPUTE d=0.
IF (hbp=0 AND alter>=14 AND alter<=17) d=1.
EXECUTE.

* Hilfsvariable e=1, wenn weitere Person im Haushalt zwischen 7 und 13 Jahre alt ist (sonst e=0).
COMPUTE e=0.
IF (hbp=0 AND alter>=7 AND alter<=13) e=1.
EXECUTE.

* Hilfsvariable f=1, wenn weitere Person im Haushalt 6 Jahre oder juenger ist (sonst f=0).
COMPUTE f=0.
IF (hbp=0 AND alter<=6) f=1.
EXECUTE.

* Anzahl der mit c=1, d=1, e=1 und f=1 markierten Personen im Haushalt.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK jahr hhnr
   / anz_c=SUM(c)
   / anz_d=SUM(d)
   / anz_e=SUM(e)
   / anz_f=SUM(f).
EXECUTE.

* Berechnung des Aequivalenzeinkommens.
IF einkh_2>=0 aeq_3=einkh_2 / (1+(anz_c*0.8)+(anz_d*0.9)+(anz_e*0.65)+(anz_f*0.5)).
IF einkh_2<0 aeq_3=einkh_2.
EXECUTE.


*---------------------------------------   Ausschluss temporaerer Hilfsvariablen   ----------------------------------------.

DELETE VARIABLES  a  b  c  d  e  f  anz_a  anz_b  anz_c  anz_d  anz_e
   anz_f  hbp  sth_t.
EXECUTE.

