﻿* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Erwerbstaetigkeit
* Mikrozensus Scientific Use File 1995

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: erwerb95.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

COMPUTE jahr=1995.

* Versionsnummer des Moduls 'Erwerbstaetigkeit'.
COMPUTE vers_erw=5.


*-----------------------------   Mithelfende Familienangehoerige oder Gelegeheitstaetigkeit   -----------------------------.

COMPUTE mith=ef62.
RECODE mith (2, 9=0).
EXECUTE.


*--------------------------------------------   Geringfuegige Beschaeftigung   --------------------------------------------.

COMPUTE gebes=ef75.
RECODE gebes (8=-2) (0=-1) (9=0).
EXECUTE.


*---------------------------------------   Erwerbstaetigkeit: Mikrozensus-Konzept   ---------------------------------------.

COMPUTE erw_1=ef34.
RECODE erw_1 (1, 2, 3, 4=1) (5, 6, 7=2) (8, 9=3).
EXECUTE.


*-------------------------------------------   Erwerbstaetigkeit: ILO-Konzept   -------------------------------------------.

COMPUTE erw_2=erw_1.
IF (erw_2=2 AND ef68~=1) erw_2=3.
EXECUTE.


*------------------------------------------------   2. Erwerbstaetigkeit   ------------------------------------------------.

COMPUTE zwerw=ef91.
RECODE zwerw (9=0).
EXECUTE.


*--------------------------------   Normalerweise geleistete Arbeitszeit (Std.) je Woche   --------------------------------.

COMPUTE abstd_1=ef97.
RECODE abstd_1 (50=50.5) (57=58) (61=61.5) (67=68) (70=70.5) (72=73)
   (76=76.5) (78=78.5) (81=82.5) (85=87) (91=94) (99=0).
EXECUTE.


*---------------------------------   Tatsaechliche Arbeitszeit (Berichtswoche: Stunden)   ---------------------------------.

COMPUTE abstd_2=ef99.
RECODE abstd_2 (68=68.5) (71=71.5) (73=73.5) (78=78.5) (81=82) (86=87.5)  (91=92.5)
   (96=96.5) (99=0).
EXECUTE.


*-------------------------------------------------   Stellung im Beruf   --------------------------------------------------.

COMPUTE stib_1=ef94.
RECODE stib_1 (0, 1=1) (6, 7=6) (9=-2).
IF (erw_1=2 OR erw_1=3) stib_1=-2.
EXECUTE.


*------------------------------------------------   Vollzeit oder Teilzeit  -----------------------------------------------.

COMPUTE vztz=ef96.
RECODE vztz  (2,3,4,5,6=2)  (9=-2).
EXECUTE.


*------------------------------------------------   Befristet/Unbefristet   -----------------------------------------------.

COMPUTE frist_1=ef95.
RECODE frist_1  (1=2) (2=1) (0=-1)  (9=-2).
EXECUTE.


*------------------------------------------------   Oeffentlicher Dienst   ------------------------------------------------.

COMPUTE oeff=ef90.
RECODE oeff (8, 9=0) (0=-1).
IF (erw_1=2 OR erw_1=3) oeff=0.
EXECUTE.


*-------------------------------------------------   Arbeitslosigkeit   ---------------------------------------------------.

COMPUTE alo_1=ef65.
RECODE alo_1  (1, 2=1) (3,9=0).
EXECUTE.

COMPUTE alo_2=ef65.
RECODE alo_2  (3,9=0).
EXECUTE.


*-----------------------------------------------   Beruf nach KldB 1992   -----------------------------------------------.

COMPUTE beruf_2=ef93.
RECODE beruf_2 (031,032=031) (071,072=071) (101,102,112=101) (172,173=172) (175,176=175)
   (212,213=212) (224,225,229,231,233,234,235=225) (250,252=250) (290,291,292,293,294,295=290)
   (308,309=308) (331,332=331) (344,349=344) (353,354,359=353) (371,372,373,374,376,378=371)
   (421,422,423,424=421) (471,472=471) (480,481,484=481) (505,506=505) (512,514=512) (605,606=605)
   (625,626,629=625) (721,723,724=721) (731,732=732) (880,887=880) (981,982,983=981) (999=-2).
IF (erw_1=2 OR erw_1=3) beruf_2=-2.
EXECUTE.


*-------------------------------------------   Berufsklassifikation: Blossfeld   -------------------------------------------.

COMPUTE bk=ef93.
RECODE bk (011,012,013,014,023,024,051,053,061,062=1)
   (070,071,072,080,101,112,121,131,135,141,145,150,152,153,
   161,162,164,176,179,181,185,191,194,211,212,213,222,224,
   225,229,231,233,234,235,241,245,252,313,321,322,323,332,
   341,344,349,352,353,354,358,359,361,371,373,376,393,424,
   431,435,440,442,443,460,461,463,465,466,471,472,482,
   486,488,512,514,521,522,523,531,540,544,545,546,549,550=2)
   (142,171,173,174,175,178,201,220,221,250,254,255,256,
   259,261,264,265,266,267,268,269,270,273,274,276,278,281,
   282,283,287,290,292,293,294,295,300,302,305,
   307,308,309,310,311,312,315,316,317,318,331,351,372,374,
   378,391,392,401,411,421,423,441,480,483,484,485,487,
   491,492,501,502,505,506,510,511,541,991=3)
   (303,304,620,621,622,623,624,625,626,627,628,629,631,632,
   633,634,641,642,651,652,721,857=4)
   (032,052,600,601,602,603,604,605,606,607,608,609,611,
   612,726,883=5)
   (685,686,706,713,714,715,716,723,724,741,742,743,744,791,
   792,793,794,795,796,805,838,911,912,914,915,923,931,
   934,935,936,937=6)
   (172,675,704,705,711,712,801,802,803,804,812,814,831,832,
   833,834,835,836,837,851,852,854,855,856,858,859,894,901,
   902,921=7)
   (821,822,823,853,861,862,863,864,865,866,867,868,869,870,
   873,874,875,876,878,879=8)
   (811,813,841,842,843,844,871,872,880,881,882,884,885,886,
   887,891=9)
   (660,661,662,663,687,689,731,732,735,773,782,783,784,789=10)
   (031,670,671,672,673,674,676,677,678,683,691,692,695,701,
   702,703,771,772,774,775,776,777,778,779,780,785,786,787,
   788,996=11)
   (750,751,753,754,755,756,757,761,763,764,765=12)
   (ELSE=0).
IF (erw_1=2 OR erw_1=3) bk=-2.
EXECUTE.


*-------------------------------------------   Bildung der MPS-Berufsvariable   -------------------------------------------.

COMPUTE mps=ef93.
RECODE mps 
   (0=-2) (11=35.1) (12=42.7) (13=30.1) (14=30.0) (23=41.1) (24=33.4)
   (31=79.7) (32=84.9) (51=32.4) (52=64.9) (53=52.9) (61=64.0) (62=31.8)
   (70=35.3) (71=35.3) (72=46.1) (80=35.9) (101=47.2) (112=31.2) (121=31.7)
   (131=35.6) (135=33.1) (141=36.8) (142=49.1) (145=34.6) (150=32.8) 
   (152=32.8) (153=32.8) (161=32.9) (162=31.5) (164=32.1) (171=51.2)
   (172=50.3)(173=50.3) (174=48.9)(175=35.1)(176=49.9)(178=39.5)(179=39.5)
   (181=31.2)(185=35.3)(191=33.4)
   (194=32.1)(201=35.0)(211=31.9)(212=32.1)(213=32.9)(220=32.0) (221=35.9)
   (222=33.5)(224=36.1)(225=32.9)(229=32.0)(231=32.4)(233=39.2)(234=35.6)
   (235=36.2)(241=35.4)(245=35.2)(250=38.8)(252=36.1)(254=38.8)(255=37.5)
   (256=38.8)(259=38.8)(261=39.3)(264=44.2)(265=39.3)(266=43.6)(267=44.2)
   (268=44.2)(269=44.2)(270=43.6)(273=40.8)(274=37.4)(276=43.6)(278=43.6)
   (281=46.0)(282=42.8)(283=49.1)(287=39.3)(290=41.6)(292=41.6)(293=41.6)
   (294=41.6)(295=47.4)(300=47.4)(302=54.0)(303=64.9)(304=72.2)(305=45.2)
   (307=47.4)(308=53.6)(309=48.4)(310=47.7)(311=47.7)(312=48.6)(313=44.3)
   (315=50.2)(316=50.2)(317 =50.2)(318=47.7)(321=35.6)(322=38.5)(323=31.7)
   (331=31.5)(332=32.6)(341=35.2)(344=35.6)(349=33.7)(351=48.0)(352=33.5)
   (353=33.0)(354=34.2)(358=34.2)(359=35.4)(361=35.0)(371=36.1)(372=50.2)
   (373=30.3)(374=40.7)(376=32.2)(378=53.2)(391=51.6)(392=52.5)(393=33.0)
   (401=52.3)(411=45.1)(421=42.7)(423=35.8)(424=38.5)(431=41.1)(435=41.1)
   (440=39.2)(441=39.2)(442=39.2)(443=37.2)(460=44.2)(461=32.1)(463=32.7)
   (465=33.1)(466=44.2)(471=30.3)(472=30.2)(480=41.3)(482=42.8)
   (483=47.8)(484=49.1)(485=40.9)(486=39.2)(487=41.7)(488=38.7)(491=49.6)
   (492=35.4)(501=42.5)(502=41.4)(505=42.5)(506=37.3)(510=44.2)(511=44.2)
   (512=36.4)(514=46.1)(521=43.1)(522=32.1)(523=43.1)(531=31.0)(540=34.2)
   (541=42.5)(544=32.2)(545=32.5)(546=33.1)(549=34.2)(550=36.1)(600=88.3)
   (601=103.5)(602=89.6)(603=111.7)(604=85.7)(605=91.0)(606=104.6)(607=88.3)
   (608=88.3)(609=111.7)(611=123.9)(612=125.2)(620=67.5)(621=69.7)(622=61.8)
   (623=71.2)(624=53.4)(625=91.0)(626=72.1)(627=67.7)(628=67.5)(629=67.5)
   (631=60.7) (632=50.2)(633=53.1)(634=53.1)(641=52.7)(642=52.7)(651=63.9)
   (652=63.9)(660=51.1) (661=51.1)(662=51.1)(663=51.1)(670=78.0)(671=78.0)
   (672=78.0)(673=78.0)(674=80.7) (675=69.7)(676=78.0)(677=78.0)(678=78.0)
   (683=80.7)(685=51.6)(686=46.1)(687=68.8)(689=68.8)(691=74.1)(692=68.9)
   (695=71.0)(701=61.0)(702=69.2)(703=71.9)(704=80.6)
   (705=54.2)(706=47.8)(711=50.1)(712=49.5)(713=51.8)(714=35.1)(715=35.1)
   (716=35.5)(721=80.3)(723=46.1)(724=49.8)(726=79.8)(731=52.5)(732=48.3)
   (735=50.3)(741=37.1) (742=31.1)(743=36.2)(744=31.5)(750=101.3)(751=101.3)
   (753=106)(754=106)(755=90.1)(756=90.1)(757=90.1)(761=153.5)(763=80.0)
   (764=84.7)(765=84.7)(771=68.9)(772=64.7)(773=53.3)(774=79.6)(775=79.6)
   (776=79.6)(777=79.6)(778=79.6)(779=79.6)(780=60.4)(782=53.2)(783=53.3)
   (784=42.9)(785=60.4)(786=60.4)(787=60.4)(788=60.4)(789=53.2)
   (791=46.2)(792=36.5)(793=39.1)(794=36.1)(795=67.6)(796=39.1)(801=63.0)
   (802=52.9)(803=53.1)(804=61.1)(805=51.7)(811=138.2)(812=84.7)(813=145.7)
   (814=53.5)(821=85.4)(822=80.9)(823=80.3)(831=78.1)(832=80.4)(833=69.1)
   (834=69.1)(835=54.1)(836=53.6)(837=64.1)(838=56.7)(841=191.3) 
   (842=216) (843=138.9) (844=207.2)(851=80.8)(852=61.2)(853=51.5)(854=43.1)
   (855=68.9)(856=52.9)(857=53.2)(858=68.9)(859=61.2)(861=62.3)(862=62.3)
   (863=62.3)(864=62.3)(865=62.3)(866=62.3)(867=62.3)(868=80.3)(869=62.3)
   (870=120.0)(871=152.5)(872=132.1)(873=120.0)(874=104.6)(875=80.9)
   (876=67.6)(878=71.4)(879=71.4)(880=122.2)(881=135.7)(882=122.2)(883=139.8)
   (884=135.7)(885=122.2)(886=135.7)(887=135.7)(891=122.0)(894=54.7)
   (901=60.6)(902=44.4)(911=53.9)(912=38.8)(914=53.9)(915=38.5)(921=64.4)
   (923=37.4)(931=45.4)(934=32.3)(935=32.6)(936=32.5)(937=32.3) (ELSE=0).
IF (erw_1=2 OR erw_1=3) mps=-2.
EXECUTE.


*-------------------------------------------------   Wirtschaftssektor   --------------------------------------------------.

COMPUTE sek=ef92.
RECODE sek (11 THRU 145=1) (151 THRU 455=2) (501 THRU 990=3) (999=-2).
IF (erw_1=2 OR erw_1=3) sek=-2.
EXECUTE.

