﻿* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Gesundheit
* Mikrozensus Scientific Use File 2003

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: ges03.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

* Erhebungsjahr.
COMPUTE jahr=2003.

* Versionsnummer des Moduls 'Gesundheit'.
COMPUTE vers_ges=5.


*-----------------------------------------------------   Ernaehrung   -----------------------------------------------------.

* Groesse.
RECODE EF409 (40,51=51) (78,79=78) (200,201=200) (203 THRU 205=203) (999=-1) (0=-2) (ELSE=COPY) INTO centi.

* Gewicht.
RECODE EF410 (118,119=118) (126,128=126) (140,145=140) (161,171=161) (999=-1) (0=-2) (ELSE=COPY) INTO kilo.


*------------------------------------------------------   Rauchen   -------------------------------------------------------.

* gegenwaertiger Raucher.
RECODE EF411 (0=-2) (1=1) (2=2) (9=-1) (8=3) INTO rauje.

* ehemaliger Raucher.
RECODE EF412 (0=-2) (1=1) (2=2) (9=-1) (8=3) INTO raueh.

* Alter bei Rauchbeginn.
RECODE EF413 (99=-1) (0=-2) (41 THRU 42=41) (46 THRU 49=46) (51 THRU 53=51)
   (55 THRU 56=55) (65=60) (ELSE=COPY) INTO raube.

* Art des Gerauchten.
RECODE EF414 (0=-2) (9=-1) (ELSE=COPY) INTO rauar.

* Anzahl taeglich gerauchter Zigaretten.
RECODE EF415 (0=-2) (9=-1) (ELSE=COPY) INTO rauzi.


*-----------------------------------------------   Krankheit und Unfaelle   -----------------------------------------------.

* Grippeimpfung.
RECODE EF408 (0=-2) (1=1) (8=2) (9=-1) INTO impf.

* Krankheit/Unfallverletzung in den letzten vier Wochen.
RECODE EF402 (0=-2) (1=1) (2=2) (9=-1) (8=3) INTO krank.

* Krankheit/Unfallverletzung: gegenwaertiges Andauern.
RECODE EF405 (0=-2) (1=1) (9=-1) (8=2) INTO krje.

* Krankheit/Unfallverletzung: Dauer.
RECODE EF406 (0=-2) (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (9=-1) INTO krdau.

* Arzt-/Krankenhausbehandlung.
RECODE EF407 (0=-2) (9=-1) (1=1) (2=2) (3=3) (8=4) INTO behan.

* Unfallverletzung: Art des Unfalls.
RECODE EF404 (0=-2) (9=-1) (ELSE=COPY) INTO unfal.

* Krankheit: Verursachung oder Verschlechterung durch Erwerbstaetigkeit.
RECODE EF403 (0=-2) (9=-1) (1=1) (8=2) INTO krerw.


*------------------------------------------------   Pflegebeduerftigkeit   ------------------------------------------------.

* Hillfs- oder Pflegebeduerftigkeit.
RECODE EF316 (0=-2) (1=1) (8=2) (9=-1) INTO hilfe.

* Hilfsbeduerftigkeit: Koerperpflege.
RECODE EF317 (0=-2) (1=1) INTO hilfk.
IF ((EF316=1) AND (hilfk=-2)) hilfk=2.
COUNT hi = EF317 to EF320 (1, 2, 3, 4).
IF EF316=1 AND hi=0 hilfk=-1.

* Hilfsbeduerftigkeit: Ernaehrung.
RECODE EF318 (0=-2) (2=1) INTO hilfn.
IF ((EF316=1) AND (hilfn=-2)) hilfn=2.
COUNT hi = EF317 to EF320 (1, 2, 3, 4).
IF EF316=1 AND hi=0 hilfn=-1.

* Hilfsbeduerftigkeit: Beweglichkeit.
RECODE EF319 (0=-2) (3=1) INTO hilfb.
IF ((EF316=1) AND (hilfb=-2)) hilfb=2.
COUNT hi = EF317 to EF320 (1, 2, 3, 4).
IF EF316=1 AND hi=0 hilfb=-1.

* Hilfsbeduerftigkeit: Versorgung.
RECODE EF320 (0=-2) (4=1) INTO hilfv.
IF ((EF316=1) AND (hilfv=-2)) hilfv=2.
COUNT hi = EF317 to EF320 (1, 2, 3, 4).
IF EF316=1 AND hi=0 hilfv=-1.

* Hilfsbeduerftigkeit: Haeufigkeit.
RECODE EF325 (0=-2) (1=1) (2=2) (3=3) (4=4) (5=5) (9=-1) INTO hilfh.

* Leistungen aus Pflegeversicherung.
RECODE EF326 (0=-2) (8=2) (1=1) (9=-1) INTO pflei.

* Pflegestufe.
RECODE EF327 (0=-2) (1=1) (2=2) (3=3) (9=-1) INTO pfstu.


*-----------------------------------------------------   Behinderung   ----------------------------------------------------.

* Behinderung: amtlicher Bescheid/Antrag.
RECODE EF400 (0=-2) (1 THRU 3=1) (4=2) (8=2) (9=-1) INTO behin.

* Behinderung: Grad.
RECODE EF401 (1=1) (2=1) (3=2) (4=2) (5=3) (6=4) (7=5) (8=6) (9=7) (10=8) (99=-1) (0=-2) INTO behgd.


*-------------------------------------------------   Krankenversicherung   ------------------------------------------------.

* Krankenversicherung.
RECODE EF250 (1=1) (8=2) (9=-1) INTO kavrs.

* Krankenversicherung: Kassentyp (8 Kategorien).
RECODE EF251 (0=8) (3=1) (4=3) (5=4) (6=1) (7=5) (8=6) (9=7) (99=8) (ELSE=COPY) INTO katyp_1.

* Krankenversicherung: Kassentyp (10 Kategorien).
RECODE EF251 (0=10) (99=10) (ELSE=COPY) INTO katyp_2.

* Art der Krankenversicherung.
RECODE EF252 (0=7) (9=7) (ELSE=COPY) INTO kaart.

* Krankenversicherung: zusaetzlich privat.
RECODE EF253 (1=1) (8=2) (0=-2) (9=-2) INTO kapri.
EXECUTE.

