﻿* Encoding: UTF-8.
*--------------------------------------------------------------------------------------------------------------------------.

* Kumulation der Mikrozensen 1962 bis 2016

* SPSS-Syntax zur Generierung harmonisierter Variablen
* Themenbereich Gesundheit
* Mikrozensus Scientific Use File 1995

*--------------------------------------------------------------------------------------------------------------------------.

* Dateiname: ges95.sps
* Version: 5

* IBM SPSS Statistics Version 24.0

* Bei Nutzung dieses Programmcodes bitte zitieren:
  Lengerer, Andrea; Schroedter, Julia H.; Boehle, Mara; Wolf, Christof (2020):
  Datenhandbuch GESIS Mikrozensus-Trendfile. Harmonisierung der Mikrozensen 1962 bis 2016
  GESIS Papers 2020/18. Mannheim: GESIS

* GESIS - Leibniz-Institut fuer Sozialwissenschaften
  German Microdata Lab
  https://www.gesis.org/gml
  gml@gesis.org

*--------------------------------------------------------------------------------------------------------------------------.





*---------------------------------------------------   Vorbereitungen   ---------------------------------------------------.

MISSING VALUES ALL ().

* Erhebungsjahr.
COMPUTE jahr=1995.

* Versionsnummer des Moduls 'Gesundheit'.
COMPUTE vers_ges=5.


*-----------------------------------------------------   Ernaehrung   -----------------------------------------------------.

* Jodverwendung.
RECODE EF87 (0=0) (1=1) (9=2) (8=-2) INTO jodve.
IF ((uspg=1) AND (jodve=-2)) jodve = -1.

* Grund fuer Nichtverwendung von Jodsalz.
RECODE EF88 (1=1) (2=2) (3=3) (9=-2) INTO jodgr.
IF (((EF87=0) OR (EF87=9)) AND (jodgr=-2)) jodgr = -1.


*------------------------------------------------------   Rauchen   -------------------------------------------------------.

* gegenwaertiger Raucher.
RECODE EF166u9 (0=-2) (1=1) (2=2) (9=3) INTO rauje.
IF ((uspg=1) AND (rauje=-2)) rauje=-1.

* ehemaliger Raucher.
RECODE EF166u11 (0=-2) (1=1) (2=2) (9=3) INTO raueh.
IF ((EF166u9=9) AND (raueh=-2)) raueh = -1.

* Alter bei Rauchbeginn.
RECODE EF166u10 (0=-2) (46 THRU 48=46) (55 THRU 56=55) (65=60) (ELSE=COPY) INTO raube.
IF (((EF166u9=1) OR (EF166u9=2) OR (EF166u11=1) OR (EF166u11=2)) AND (raube=-2)) raube = -1.

* Art des Gerauchten.
RECODE EF149 (1=1) (2=2) (3=3) (9=-2) INTO rauar.
IF (((EF166u9=1) OR (EF166u9=2) OR (EF166u11=1) OR (EF166u11=2)) AND (rauar=-2)) rauar= -1.

* Anzahl taeglich gerauchter Zigaretten.
RECODE EF150 (1=1) (2=2) (3=3) (4=4) (9=-2) INTO rauzi.
IF ((EF149=1) AND (rauzi=-2)) rauzi=-1.


*-----------------------------------------------   Krankheit und Unfaelle   -----------------------------------------------.

* Krankheit/Unfallverletzung in den letzten vier Wochen.
RECODE EF166u2 (0=-1) (1=1) (2=2) (9=3) (8=-2) INTO krank.

* Krankheit/Unfallverletzung: gegenwaertiges Andauern.
RECODE EF166u3 (0=-2) (1=1) (9=2) INTO krje.
IF (((EF166u2=1) OR (EF166u2=2)) AND (krje=-2)) krje=-1.

* Krankheit/Unfallverletzung: Dauer.
RECODE EF166u4 (0=-2) (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) INTO krdau.
IF (((EF166u2=1) OR (EF166u2=2)) AND (krdau=-2)) krdau=-1.

* Arzt-/Krankenhausbehandlung.
RECODE EF166u5 (0=-2) (1=1) (2=2) (3=3) (9=4) INTO behan.
IF (((EF166u2=1) OR (EF166u2=2)) AND (behan=-2)) behan=-1.

* Stationaere Krankenhausbehandlung: Dauer.
RECODE EF166u6 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (9=-2) INTO kkhda.
IF ((EF166u5=3) AND (kkhda=-2)) kkhda=-1.

* Arbeitsunfaehigkeit.
RECODE EF166u7 (0=-2) (1=1) (2=2) (9=3) INTO arbun.
IF (((EF166u2=1) OR (EF166u2=2)) AND (arbun=-2)) arbun=-1.

* Unfallverletzung: Art des Unfalls.
RECODE EF166u8 (9=-2) (ELSE=COPY) INTO unfal.
IF ((EF166u2=2) AND (unfal=-2)) unfal=-1.


*-----------------------------------------------------   Behinderung   ----------------------------------------------------.

* Behinderung: amtlicher Bescheid/Antrag.
RECODE EF167u1 (0=-2) (1 THRU 3=1) (4=2) (9=2) INTO behin.
IF ((uspg=1) AND (behin=-2)) behin=-1.

* Behinderung: Grad.
RECODE EF249 (2=1) (3=2) (4=2) (5=3) (6=4) (7=5) (8=6) (9=7) (10=8) (11=9) (99=-2) INTO behgd.
IF (((EF167u1=1) OR (EF167u1=2) OR (EF167u1=3)) AND (behgd=-2)) behgd=-1.
RECODE behgd (9=-1) (ELSE=COPY).


*-------------------------------------------------   Krankenversicherung   ------------------------------------------------.

* Krankenversicherung: Kassentyp (8 Kategorien).
RECODE EF76 (0=8) (3=1) (4=3) (5=4) (6=1) (7=5) (8=6) (9=7) (ELSE=COPY) INTO katyp_1.

* Krankenversicherung: Kassentyp (10 Kategorien).
RECODE EF76 (0=10) (ELSE=COPY) INTO katyp_2.

* Art der Krankenversicherung.
RECODE EF77 (9=7) (ELSE=COPY) INTO kaart.

* Krankenversicherung: zusaetzlich privat.
RECODE EF78 (1=1) (9=2) (0=-2) INTO kapri.
EXECUTE.

